@@ -183,6 +183,7 @@ INSTALLED_APPS = (
     'captcha',
     'south',
     'tastypie',
+    'tendenci',
     'tendenci.libs.model_report',
 
     'tendenci.apps.entities',
@@ -396,6 +397,7 @@ AUTHNET_MD5_HASH_VALUE = ''
 # FIRSTDATA
 FIRSTDATA_POST_URL = 'https://secure.linkpt.net/lpcentral/servlet/lppay'
 FIRSTDATAE4_POST_URL = 'https://checkout.globalgatewaye4.firstdata.com/payment'
+#FIRSTDATAE4_POST_URL = 'https://globalgatewaye4.firstdata.com/pay'
 
 AUTHNET_CIM_API_TEST_URL = "https://apitest.authorize.net/xml/v1/request.api"
 AUTHNET_CIM_API_URL = "https://api.authorize.net/xml/v1/request.api"
